;;; init.el -*- lexical-binding: t; -*-

;; This file controls what Doom modules are enabled and what order they load
;; in. Remember to run 'doom sync' after modifying it!

;; NOTE Press 'SPC h d h' (or 'C-h d h' for non-vim users) to access Doom's
;;      documentation. There you'll find a link to Doom's Module Index where all
;;      of our modules are listed, including what flags they support.

;; NOTE Move your cursor over a module's name (or its flags) and press 'K' (or
;;      'C-c c k' for non-vim users) to view its documentation. This works on
;;      flags as well (those symbols that start with a plus).
;;
;;      Alternatively, press 'gd' (or 'C-c c d') on a module to browse its
;;      directory (for easy access to its source code).

(doom!
 ;; :private
 ;; meow

 :completion
 (vertico +orderless +icons)           ; the search engine of the future
 (corfu +orderless +icons +dabbrev)

 :ui
 doom              ; what makes DOOM look the way it does
 doom-dashboard    ; a nifty splash screen for Emacs
 (emoji +unicode)  ; 🙂
 hl-todo           ; highlight TODO/FIXME/NOTE/DEPRECATED/HACK/REVIEW
 ligatures         ; ligatures and symbols to make your code pretty again
 minimap           ; show a map of the code on the side
 modeline          ; snazzy, Atom-inspired modeline, plus API
 nav-flash         ; blink cursor line after big motions
 ophints           ; highlight the region an operation acts on
 (popup +all +defaults)   ; tame sudden yet inevitable temporary windows
 tabs              ; a tab bar for Emacs
 (treemacs +icons)          ; a project drawer, like neotree but cooler
 unicode           ; extended unicode support for various languages
 (vc-gutter +pretty) ; vcs diff in the fringe
 vi-tilde-fringe   ; fringe tildes to mark beyond EOB
 window-select     ; visually switch windows
 workspaces        ; tab emulation, persistence & separate

 :editor
 file-templates    ; auto-snippets for empty files
 fold              ; (nigh) universal code folding
 format            ; automated prettiness
 parinfer          ; turn lisp into python, sort of
 snippets          ; my elves. They type so I don't have to
 word-wrap         ; soft wrapping with language-aware indent

 :emacs
 (dired)             ; making dired pretty [functional]
 electric          ; smarter, keyword-based electric-indent
 (ibuffer)         ; interactive buffer management
 undo              ; persistent, smarter undo for your inevitable mistakes
 vc                ; version-control and Emacs, sitting in a tree

 :term
 vterm             ; the best terminal emulation in Emacs

 :checkers
 syntax              ; tasing you for every semicolon you forget
 (spell +flyspell) ; tasing you for misspelling mispelling

 :tools
 biblio            ; Writes a PhD for you (citation needed)
 debugger          ; FIXME stepping through code, to help you add bugs
 direnv
 docker
 editorconfig      ; let someone else argue about tabs vs spaces
 ein               ; tame Jupyter notebooks with emacs
 (eval +overlay)    ; run code, run (also, repls)
 (lookup +dictionary +offline +docsets)              ; navigate your code and its documentation
 (lsp +peak)               ; M-x vscode
 magit             ; a git porcelain for Emacs
 make              ; run make tasks from Emacs
 pdf               ; pdf enhancements
 tree-sitter       ; syntax and parsing, sitting in a tree...
 upload            ; map local to remote projects via ssh/ftp

 :os
 tty               ; improve the terminal Emacs experience

 :lang
 (cc +lsp +tree-sitter)
 common-lisp       ; if you've seen one lisp, you've seen them all
 (clojure +lsp +tree-sitter)
 data              ; config/data formats
 emacs-lisp        ; drown in parentheses
 gdscript          ; the language you waited for
 (json +lsp +tree-sitter)              ; At least it ain't XML
 (java +lsp +tree-sitter)       ; the poster child for carpal tunnel syndrome
 (javascript +lsp +tree-sitter)        ; all(hope(abandon(ye(who(enter(here))))))
 (lua +tree-sitter)               ; one-based indices? one-based indices
 (markdown +tree-sitter)          ; writing docs for people to ignore
 (nix +tree-sitter +lsp)               ; I hereby Declare "nix geht mehr!"
 (org +pretty +dragndrop)               ; organize your plain life in plain text
 (php +tree-sitter)               ; perl's insecure younger brother
 (python +lsp +tree-sitter)            ; beautiful is better than ugly
 (racket +lsp)            ; a DSL for DSLs
 (ruby +tree-sitter)     ; 1.step {|i| p "Ruby is #{i.even? ? 'love' : 'life'}"}
 (rust +lsp +tree-sitter)       ; Fe2O3.unwrap().unwrap().unwrap().unwrap()
 (scheme +guile)   ; a fully conniving family of lisps
 (sh +lsp +tree-sitter)                ; she sells {ba,z,fi}sh shells on the C xor
 (web +lsp +tree-sitter)
 (yaml +tree-sitter)              ; JSON, but readable


 :email
 (mu4e +mbsync)

 :app
 ;;calendar
 ;; emms

 :config
 (default +smartparens))
